#!/bin/sh

. /etc/utils/shell-utils.sh
DEBUG=0

retVal=0
WIFI_STARTUP_SCRIPT=/etc/init.d/wifi.sh
WIFI_DRIVER_MODULE_NAME="ralink"
LOCK_WIFI_ID_FILE=/ram/lock/wifi-id.lock

_check_lock_and_delete()
{
  if [ $LOCK_OWNED -gt 0 ]; then
    #log "Lock owned. Deleting lock..."
    rm -f $LOCK_FILE
  fi
}

_exit()
{
  #_check_lock_and_delete

  exit 0;
}
_error()
{
  exit 1;
}

_export_vendor_id()
{
  if [ "$1" == "0b05" ]; then
    log "found vendor = ASUS(0x0b05)"
    if [ "$2" == "1784" ]; then
      log "found product = USB-N13(0x1784)"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "07d1" ]; then
    log "found vendor = D-Link System (0x07d1)"
    if [ "$2" == "3c0d" ]; then
      log "found product = DWA-125 Wireless 150 USB Adapter"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "07d1" ]; then
    log "found vendor = D-Link System (0x07d1)"
    if [ "$2" == "3c16" ]; then
      log "found product = DWA-125 Wireless N 150 Adapter (rev.A2)"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "2001" ]; then
    log "found vendor = D-Link System (0x07d1)"
    if [ "$2" == "3c19" ]; then
      log "found product = DWA-125 Wireless N 150 Adapter (rev.A3)"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "7392" ]; then
    log "found vendor = Edimax (0x7392)"
    if [ "$2" == "7711" ]; then
      log "found product = EW-7711UAn (0x7711)"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "148f" ]; then
    log "found vendor = Ralink Technology, Corp. (0x148f)"
    if [ "$2" == "3070" ] || [ "$2" == "5370" ]; then
      log "found product = RT2870/RT3070 Wireless Adapter (0x3070)"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "1737" ]; then
    log "found vendor = Ralink Technology, Corp. (0x148f)"
    if [ "$2" == "0079" ] || [ "$2" == "0079" ]; then
      log "WUSB600N"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if [ "$1" == "7392" ]; then
    log "found vendor = Ralink Technology, Corp. (0x148f)"
    if [ "$2" == "7733" ] || [ "$2" == "7733" ]; then
      log "WUSB600N"
      export wifi_driver=$WIFI_DRIVER_MODULE_NAME
      retVal=1
      return
    fi
  fi

  if echo $4 | grep -i "ralink" > /dev/null ; then
    log "found vendor = Ralink Technology, Corp. (common case)"
    export wifi_driver=$WIFI_DRIVER_MODULE_NAME
    retVal=1
    return
  fi

    log "going to test mfct = ${USB_MANUFACTURER}"

    if echo "${USB_MANUFACTURER}" | grep -i "ralink" > /dev/null ; then
	log "Found device of 'Ralink Technology' manufacturer. Trying it..."
	export wifi_driver=$WIFI_DRIVER_MODULE_NAME
	retVal=1
	return
    fi

    if echo "${USB_PRODUCT}" | egrep -i "(802.11)|(WLAN)|(80211)|(wireless)" > /dev/null ; then
	log "Found '802.11n WLAN Adapter' product family device. Trying it..."
	export wifi_driver=$WIFI_DRIVER_MODULE_NAME
	retVal=1
	return
    fi

  export wifi_driver=
  retVAL=0;
}

# EXECUTION POINT

if [ "${DEVTYPE}" != "usb_interface" ]; then
    _error
fi

log "ACTION=${UDEV_ACTION}"
log "USB DEVICE PATH=${DEVPATH}"
log "USB_VENDOR_ID=$USB_VENDOR_ID, USB_PRODUCT_ID=$USB_PRODUCT_ID, USB_PRODUCT=${USB_PRODUCT}, USB_MANUFACTURER=${USB_MANUFACTURER}"

if [ "${DEVPATH}" == "" ]; then
    log "DEVPATH is not set"
    _error
fi

if [ "$UDEV_ACTION" == "" ]; then
    log "UDEV_ACTION is not set"
    _error
fi

if [ "$USB_VENDOR_ID" == "0000" ]; then
  log "USB_VENDOR_ID is not set"
  _error
fi

export wifi_bus_id=${DEVPATH}

case $UDEV_ACTION in
  add)
    if [ -f $LOCK_WIFI_ID_FILE ]; then
	_error
    fi

    _export_vendor_id $USB_VENDOR_ID $USB_PRODUCT_ID $USB_PRODUCT $USB_MANUFACTURER
    if [ $retVal -ne 1 ]; then
	log "Current device not supported USB_VENDOR_ID=$USB_VENDOR_ID USB_PRODUCT_ID=$USB_PRODUCT_ID"
	_error
    fi
    echo "${wifi_bus_id}" > $LOCK_WIFI_ID_FILE
    $WIFI_STARTUP_SCRIPT start
  ;;
  remove)
    curr_wifi_id_lock=`cat $LOCK_WIFI_ID_FILE`
    if [ "${wifi_bus_id}" == "$curr_wifi_id_lock" ]; then
	rm -f $LOCK_WIFI_ID_FILE
        $WIFI_STARTUP_SCRIPT stop
    else
	log "Its not the WiFi dongle we want to deal with"
    fi
  ;;
  *)
    _error
  ;;
esac

_exit
